@@ -268,8 +268,8 @@ class Profile(object):
                                  user_id):
 
         profile_models = cls.usable_django_model().objects.filter(user_id=user_id)
-        data = {profile_model.profile_id: cls.from_flat_data(data=json.loads(profile_model.data),
-                                                             user_id=user_id)
+        data = {str(profile_model.profile_id): cls.from_flat_data(data=json.loads(profile_model.data),
+                                                                  user_id=user_id)
                 for profile_model in profile_models}
         for profile_id, profile in data.items():
             profile.profile_id = profile_id
